@@ -39,7 +39,7 @@ use URI;
 
 use App::Aphra::File;
 
-our $VERSION = '0.2.4';
+our $VERSION = '0.2.5';
 
 has commands => (
   isa => 'HashRef',
@@ -158,7 +158,8 @@ sub _build_template {
       ),
     ],
     VARIABLES    => {
-      site => $self->site_vars,
+      site  => $self->site_vars,
+      aphra => $self,
     },
     INCLUDE_PATH => $self->include_path,
     OUTPUT_PATH  => $self->config->{target},
@@ -279,6 +280,11 @@ sub serve {
   App::HTTPThis->new->run;
 }
 
+has ver => (
+  is => 'ro',
+  default => $VERSION,
+);
+
 sub version {
   my $me = path($0)->basename;
   say "\n$me version: $VERSION\n";
